Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(658)

Unified Diff: chrome/browser/ui/webui/web_dialog_web_contents_delegate.cc

Issue 10534098: TabContentsWrapper -> TabContents, part 51. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/web_dialog_web_contents_delegate.cc
diff --git a/chrome/browser/ui/webui/web_dialog_web_contents_delegate.cc b/chrome/browser/ui/webui/web_dialog_web_contents_delegate.cc
index 32728a19df4461d3a1aca76f75597e1fc41602e8..25737ca4baf9f03cae7ac2e7ed68d2c2ccdeb6df 100644
--- a/chrome/browser/ui/webui/web_dialog_web_contents_delegate.cc
+++ b/chrome/browser/ui/webui/web_dialog_web_contents_delegate.cc
@@ -7,7 +7,7 @@
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/ui/browser.h"
#include "chrome/browser/ui/browser_navigator.h"
-#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
+#include "chrome/browser/ui/tab_contents/tab_contents.h"
#include "chrome/browser/ui/tabs/tab_strip_model.h"
#include "content/public/browser/web_contents.h"
@@ -91,10 +91,10 @@ Browser* WebDialogWebContentsDelegate::StaticAddNewContents(
// to find a browser matching params.profile or create a new one.
Browser* browser = NULL;
- TabContentsWrapper* wrapper = new TabContentsWrapper(new_contents);
- browser::NavigateParams params(browser, wrapper);
+ TabContents* tab_contents = new TabContents(new_contents);
+ browser::NavigateParams params(browser, tab_contents);
params.profile = profile;
// TODO(pinkerton): no way to get a wrapper for this.
// params.source_contents = source;
params.disposition = disposition;
params.window_bounds = initial_pos;
@@ -91,10 +91,10 @@ Browser* WebDialogWebContentsDelegate::StaticAddNewContents(
params.profile = profile;
- // TODO(pinkerton): no way to get a wrapper for this.
+ // TODO(pinkerton): no way to get a TabContents for this.
// params.source_contents = source;
params.disposition = disposition;
« no previous file with comments | « chrome/browser/ui/webui/tab_modal_confirm_dialog_webui.cc ('k') | chrome/browser/ui/webui/web_ui_browsertest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698